==> jc-1.4.0.tar.gz: javax/imageio/ImageIO__24ReaderFormatFilter.h <==
// final class javax.imageio.ImageIO$ReaderFormatFilter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3fa634aa9a3ed56 javax_imageio_ImageIO__24ReaderFormatFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24ReaderFormatFilter_H_
#define _JC_javax_imageio_ImageIO__24ReaderFormatFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_refs	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_nonrefs	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$refs	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$refs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$nonrefs	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$object;

typedef const struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vmethods	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtable	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24ReaderFormatFilter$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24ReaderFormatFilter$method$filter$c61550eb8d89c82b(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24ReaderFormatFilter$method_info$filter$c61550eb8d89c82b;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vmethods {
	jboolean	(*filter$c61550eb8d89c82b)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vmethods	javax_imageio_ImageIO__24ReaderFormatFilter;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_refs {
	struct _jc_java_lang_String$object	*formatName;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$refs {
    _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_refs	javax_imageio_ImageIO__24ReaderFormatFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_nonrefs	javax_imageio_ImageIO__24ReaderFormatFilter;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object {
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype _jc_javax_imageio_ImageIO__24ReaderFormatFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24ReaderFormatFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24ReaderFormatFilter$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24ReaderFormatFilter_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/ImageIO__24ReaderFormatFilter.h <==
// final class javax.imageio.ImageIO$ReaderFormatFilter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f14fe3d84d50db78 javax_imageio_ImageIO__24ReaderFormatFilter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_ImageIO__24ReaderFormatFilter_H_
#define _JC_javax_imageio_ImageIO__24ReaderFormatFilter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_refs	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_refs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_nonrefs	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$refs	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$refs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$nonrefs	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$nonrefs;
typedef struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$object;

typedef const struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vmethods	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vmethods;
typedef const struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtable	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtable;
typedef const struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype;

// Constructors
extern void _jc_javax_imageio_ImageIO__24ReaderFormatFilter$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_imageio_ImageIO__24ReaderFormatFilter$method$filter$c61550eb8d89c82b(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_ImageIO__24ReaderFormatFilter$method_info$filter$c61550eb8d89c82b;

// Virtual methods structure
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vmethods {
	jboolean	(*filter$c61550eb8d89c82b)(_jc_env *, struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vmethods	javax_imageio_ImageIO__24ReaderFormatFilter;
};

// Vtype
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype {
	_jc_type			type;
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_refs {
	struct _jc_java_lang_String$object	*formatName;
};

// Reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$refs {
    _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_refs	javax_imageio_ImageIO__24ReaderFormatFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_ImageIO__24ReaderFormatFilter$sub_nonrefs	javax_imageio_ImageIO__24ReaderFormatFilter;
};

// Object instance structure
struct _jc_javax_imageio_ImageIO__24ReaderFormatFilter$object {
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype	*vtype;
	_jc_javax_imageio_ImageIO__24ReaderFormatFilter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_ImageIO__24ReaderFormatFilter$vtype _jc_javax_imageio_ImageIO__24ReaderFormatFilter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_ImageIO__24ReaderFormatFilter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_ImageIO__24ReaderFormatFilter$class_object;

#endif	/* _JC_javax_imageio_ImageIO__24ReaderFormatFilter_H_ */
